@@ -49,7 +49,7 @@ class JOSEHeader:
             if params['enc'] not in OID_JOSE_JWE_ENC:
                 raise UnsupportedEncryptionAlgorithm(
                     f"Unsupported encryption algorithm: {params['enc']}")
-        elif params.get('alg') not in  OID_JOSE_JWS_ALG:
+        elif params.get('alg') not in ALGORITHM_MAPPING:
             raise UnsupportedAlgorithm(params['alg'])
 
         return cls(params)
